@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from brightway2 import config, databases, methods, Database, Method, \
-    JsonWrapper
+    JsonWrapper, reset_meta
 from bw2analyzer import ContributionAnalysis, DatabaseExplorer
 from bw2calc import LCA, ParallelMonteCarlo
 from flask import Flask, url_for, render_template, request, redirect, abort
@@ -9,7 +9,13 @@ from jobs import JobDispatch, InvalidJob
 from utils import get_job_id, get_job, set_job_status, json_response
 import itertools
 import math
+import multiprocessing
 import numpy as np
+import os
+import platform
+import requests
+import urllib2
+
 
 app = Flask(__name__)
 
@@ -53,6 +59,98 @@ def job_dispatch(job):
     except InvalidJob:
         abort(500)
 
+###################
+### File Picker ###
+###################
+
+
+@app.route("/filepicker")
+def fp_test():
+    return render_template("fp.html")
+
+
+@app.route("/fp-api", methods=["POST"])
+def fp_api():
+    path = urllib2.unquote(request.form["dir"])
+    try:
+        root, dirs, files = os.walk(path).next()
+    except StopIteration:
+        # Only files from now on...
+        root, dirs = path, []
+        files = os.listdir(root)
+    data = []
+    files = [x for x in files if x[0] != "."]
+    if len(files) > 20:
+        files = files[:20] + ["(and %s more files...)" % (len(files) - 20)]
+    for dir_name in dirs:
+        if dir_name[0] == ".":
+            continue
+        data.append({
+            "dir": True,
+            "path": os.path.join(root, dir_name),
+            "name": dir_name
+            })
+    for file_name in files:
+        data.append({
+            "dir": False,
+            "ext": file_name.split(".")[-1].lower(),
+            "path": os.path.join(root, file_name),
+            "name": file_name
+            })
+    return render_template("fp-select.html", dirtree=data)
+
+#######################
+### Getting started ###
+#######################
+
+
+@app.route('/start/path', methods=["POST"])
+def set_path():
+    path = urllib2.unquote(request.form["path"])
+    dirname = urllib2.unquote(request.form["dirname"])
+    dirpath = os.path.join(path, dirname)
+    if not os.path.exists(dirpath):
+        os.mkdir(dirpath)
+
+    user_dir = os.path.expanduser("~")
+    if platform.system == "Windows":
+        filename = "brightway2path.txt"
+    else:
+        filename = ".brightway2path"
+    with open(os.path.join(user_dir, filename), "w") as f:
+        f.write(dirpath)
+
+    config.reset()
+    config.create_basic_directories()
+    reset_meta()
+    return "1"
+
+
+@app.route('/start/biosphere')
+def install_biosphere():
+    # Download and format data
+    keys, values = JsonWrapper.loads(
+        requests.get("http://mutel.org/biosphere.json").content)
+    data = dict(zip([tuple(x) for x in keys], values))
+    biosphere = Database("biosphere")
+    biosphere.register(
+        format=["Handmade", -1],
+        depends=[],
+        num_processes=len(data),
+        )
+    biosphere.write(data)
+    biosphere.process()
+    return "1"
+
+
+@app.route('/start')
+def start():
+    return render_template("start.html")
+    """
+    You are currently saving your work in a temporary directory that can be deleted at any time. You can let Brightway2 create a workspace in your home directory, or you can specify a different directory by typing in the full path below:
+    """
+
+
 ###################
 ### Basic views ###
 ###################
@@ -60,42 +158,41 @@ def job_dispatch(job):
 
 @app.route('/')
 def index():
+    print config.p.get("temp_dir_ok", False)
+    print config.is_temp_dir and not config.p.get("temp_dir_ok", False)
+    if config.is_temp_dir and not config.p.get("temp_dir_ok", False):
+        print "Trying to redirect..."
+        return redirect(url_for('start'))
+    dbs = [{
+        "name": key,
+        "number": value["number"],
+        "version": value["version"]
+        } for key, value in databases.iteritems()]
+    ms = [{
+        "name": " - ".join(key),
+        "unit": value["unit"],
+        "num_cfs": value["num_cfs"]
+    } for key, value in methods.iteritems()]
     context = {
-        'databases': databases,
-        'methods': methods,
+        'databases': dbs,
+        'methods': ms,
         'config': config
         }
-    if config.is_temp_dir:
-        context["redirect"] = url_for(start_bw)
     return render_template("index.html", **context)
 
 
-@app.route('/start', methods=["GET", "POST"])
-def start_bw():
-    """Start Brightway"""
-    job_id = get_job_id()
+@app.route('/settings', methods=["GET", "POST"])
+def change_settings():
     if request.method == "GET":
-        pass
-    elif not request.form["confirm"] == "false":
-        return redirect(url_for(index) + "?temp_dir_ok=True")
-    # Starting Brightway
-    # If POST[action] = "get_biosphere":
-    set_job_status(job_id, {"action": "biosphere-import", "finished": False})
-    # Download file to disk
-    DatabaseImporter().importer(biosphere)
-    set_job_status(job_id, {"action": "biosphere-import", "finished": True})
-
-    # Step two
-    # Import IA methods
-    # Can also be from dropbox
-
-    # Step three
-    # Import Ecoinvent or other LCI database
-
-    # Step four
-    # There is no step four!
-    # Actually, there is: go to the normal homepage
-
+        context = {
+            "config": config,
+            "cpu_count": multiprocessing.cpu_count(),
+            "current_cpu_count": config.p.get("cpu_count",
+                multiprocessing.cpu_count()),
+        }
+        return render_template("settings.html", **context)
+    else:
+        return ""
 
 ###########
 ### LCA ###
